summaryrefslogtreecommitdiffstats
path: root/src/sql/drivers
diff options
context:
space:
mode:
Diffstat (limited to 'src/sql/drivers')
-rw-r--r--src/sql/drivers/cache/qsqlcachedresult.cpp2
-rw-r--r--src/sql/drivers/cache/qsqlcachedresult.h2
-rw-r--r--src/sql/drivers/ibase/qsql_ibase.h2
-rw-r--r--src/sql/drivers/mysql/qsql_mysql.cpp2
-rw-r--r--src/sql/drivers/mysql/qsql_mysql.h2
-rw-r--r--src/sql/drivers/odbc/qsql_odbc.cpp28
-rw-r--r--src/sql/drivers/odbc/qsql_odbc.h2
-rw-r--r--src/sql/drivers/psql/qsql_psql.cpp2
-rw-r--r--src/sql/drivers/psql/qsql_psql.h2
9 files changed, 22 insertions, 22 deletions
diff --git a/src/sql/drivers/cache/qsqlcachedresult.cpp b/src/sql/drivers/cache/qsqlcachedresult.cpp
index 5e46b9b4..4c841e5f 100644
--- a/src/sql/drivers/cache/qsqlcachedresult.cpp
+++ b/src/sql/drivers/cache/qsqlcachedresult.cpp
@@ -17,7 +17,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/sql/drivers/cache/qsqlcachedresult.h b/src/sql/drivers/cache/qsqlcachedresult.h
index 1cdae7ae..6d78f39d 100644
--- a/src/sql/drivers/cache/qsqlcachedresult.h
+++ b/src/sql/drivers/cache/qsqlcachedresult.h
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/sql/drivers/ibase/qsql_ibase.h b/src/sql/drivers/ibase/qsql_ibase.h
index c0e8717d..fcb73851 100644
--- a/src/sql/drivers/ibase/qsql_ibase.h
+++ b/src/sql/drivers/ibase/qsql_ibase.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/sql/drivers/mysql/qsql_mysql.cpp b/src/sql/drivers/mysql/qsql_mysql.cpp
index b0afb436..10448414 100644
--- a/src/sql/drivers/mysql/qsql_mysql.cpp
+++ b/src/sql/drivers/mysql/qsql_mysql.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/sql/drivers/mysql/qsql_mysql.h b/src/sql/drivers/mysql/qsql_mysql.h
index d47aa6ea..4d4c7b1e 100644
--- a/src/sql/drivers/mysql/qsql_mysql.h
+++ b/src/sql/drivers/mysql/qsql_mysql.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/sql/drivers/odbc/qsql_odbc.h b/src/sql/drivers/odbc/qsql_odbc.h
index b65acf6c..8583dced 100644
--- a/src/sql/drivers/odbc/qsql_odbc.h
+++ b/src/sql/drivers/odbc/qsql_odbc.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/sql/drivers/psql/qsql_psql.cpp b/src/sql/drivers/psql/qsql_psql.cpp
index 99df0fdf..788a6935 100644
--- a/src/sql/drivers/psql/qsql_psql.cpp
+++ b/src/sql/drivers/psql/qsql_psql.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/sql/drivers/psql/qsql_psql.h b/src/sql/drivers/psql/qsql_psql.h
index 217cfe45..bed3ebbc 100644
--- a/src/sql/drivers/psql/qsql_psql.h
+++ b/src/sql/drivers/psql/qsql_psql.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/sql/drivers/odbc/qsql_odbc.cpp b/src/sql/drivers/odbc/qsql_odbc.cpp
index 4d0f7969..9851e1cb 100644
--- a/src/sql/drivers/odbc/qsql_odbc.cpp
+++ b/src/sql/drivers/odbc/qsql_odbc.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -450,18 +450,18 @@ static TQSqlFieldInfo qMakeFieldInfo( const SQLHANDLE hStmt, const TQODBCPrivate
bool isNull;
TQString fname = qGetStringData( hStmt, 3, -1, isNull, p->unicode );
int type = qGetIntData( hStmt, 4, isNull ); // column type
- int retquired = qGetIntData( hStmt, 10, isNull ); // nullable-flag
- // retquired can be SQL_NO_NULLS, SQL_NULLABLE or SQL_NULLABLE_UNKNOWN
- if ( retquired == SQL_NO_NULLS ) {
- retquired = 1;
- } else if ( retquired == SQL_NULLABLE ) {
- retquired = 0;
+ int required = qGetIntData( hStmt, 10, isNull ); // nullable-flag
+ // required can be SQL_NO_NULLS, SQL_NULLABLE or SQL_NULLABLE_UNKNOWN
+ if ( required == SQL_NO_NULLS ) {
+ required = 1;
+ } else if ( required == SQL_NULLABLE ) {
+ required = 0;
} else {
- retquired = -1;
+ required = -1;
}
int size = qGetIntData( hStmt, 6, isNull ); // column size
int prec = qGetIntData( hStmt, 8, isNull ); // precision
- return TQSqlFieldInfo( fname, qDecodeODBCType( type, p ), retquired, size, prec, TQVariant(), type );
+ return TQSqlFieldInfo( fname, qDecodeODBCType( type, p ), required, size, prec, TQVariant(), type );
}
static TQSqlFieldInfo qMakeFieldInfo( const TQODBCPrivate* p, int i )
@@ -495,16 +495,16 @@ static TQSqlFieldInfo qMakeFieldInfo( const TQODBCPrivate* p, int i )
TQString qColName = TQString::fromLocal8Bit( (const char*)colName );
#endif
// nullable can be SQL_NO_NULLS, SQL_NULLABLE or SQL_NULLABLE_UNKNOWN
- int retquired = -1;
+ int required = -1;
if ( nullable == SQL_NO_NULLS ) {
- retquired = 1;
+ required = 1;
} else if ( nullable == SQL_NULLABLE ) {
- retquired = 0;
+ required = 0;
}
TQVariant::Type type = qDecodeODBCType( colType, p );
return TQSqlFieldInfo( qColName,
type,
- retquired,
+ required,
(int)colSize == 0 ? -1 : (int)colSize,
(int)colScale == 0 ? -1 : (int)colScale,
TQVariant(),
@@ -1590,7 +1590,7 @@ bool TQODBCPrivate::checkDriver() const
int i;
// check the retquired functions
for ( i = 0; reqFunc[ i ] != 0; ++i ) {
r = SQLGetFunctions( hDbc, reqFunc[ i ], &sup );
@@ -1590,7 +1590,7 @@ bool TQODBCPrivate::checkDriver() const
int i;
- // check the retquired functions
+ // check the required functions
for ( i = 0; reqFunc[ i ] != 0; ++i ) {
r = SQLGetFunctions( hDbc, reqFunc[ i ], &sup );